ToPlain

Trait ToPlain 

pub trait ToPlain {
    // Required method
    fn to_plain(&self) -> String;
}
A trait for converting a value to its Conjure PLAIN string representation.

This is implemented for all types that implement the Plain trait.

Required Methods

fn to_plain(&self) -> String

Returns the conjure PLAIN string representation of this value.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> ToPlain for T
where T: ?Sized + Plain,