pub trait ToPlain {
// Required method
fn to_plain(&self) -> String;
}Expand description
A trait for converting a value to its Conjure PLAIN string representation.
This is implemented for all types that implement the Plain trait.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".